/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/**
 * AboutPlugins.java - A Plugin to tell you what other plugins are loaded in JEdit
 * @version     0.1.1    29/01/2000    First version
 *
 * @author      Todd Papaioannou 
 * Copyright (C) 1999 Todd Papaioannou (toddp@acm.org)
 */

import org.gjt.sp.jedit.*;
import java.awt.event.ActionEvent;
import java.util.Vector;
import java.awt.*;
import javax.swing.*;

public class AboutPluginsPlugin extends EditPlugin {
    
	/**
	 * Method called by jEdit to initialize the plugin.
	 */
	public void start() {

        jEdit.addAction(new AboutAction());
	}

	/**
	 * Method called by jEdit before exiting. 
	 */
	//public void stop() {}

	/**
	 * Method called every time a view is created to set up the
	 * Plugins menu. Menus and menu items should be loaded using the
	 * methods in the GUIUtilities class, and added to the appropriate
	 * lists.
	 * @param view The view
	 * @param menus Add submenus here
	 * @param menuItems Add menuitems here
	 */
	public void createMenuItems(View view, Vector menus, Vector menuItems) {
        
		menuItems.addElement(GUIUtilities.loadMenuItem(view, "AboutPlugins"));
	}

	/**
	 * Method called every time the plugin options dialog box is
	 * displayed. Any option panes created by the plugin should be
	 * added here.
	 * @param optionsDialog The plugin options dialog box
	 *
	 * @see OptionPane
	 * @see OptionsDialog#addOptionPane(OptionPane)
	 */
	//public void createOptionPanes(OptionsDialog optionsDialog) {}

    /**
     * What happens when the plugins menu entry is selected
     *
     */
	public static class AboutAction extends EditAction	{
        
		public AboutAction() {
  
			super("AboutPlugins");
		}
        
		public void actionPerformed(ActionEvent evt) {
            new AboutPluginsUI(jEdit.getPlugins()).setVisible(true);
        }
    }
            
} /* End of Class */
