/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
/**
 * AboutPluginsUI.java - A Plugin to tell you what other plugins are loaded in JEdit.
 * In the long run the plan is to add some sort of Liveupdate type functionality where
 * plugin updates can be downloaded and installed automatically.
 * 
 * @version     0.1.2    05/02/2000    Table version
 * @version     0.1.1    29/01/2000    First version
 *
 * @author       Todd Papaioannou
 * Copyright (C) 1999 Todd Papaioannou (toddp@acm.org)
 */

import org.gjt.sp.jedit.*;
import java.awt.event.*;
import java.util.Vector;
import java.awt.*;
import javax.swing.*;

public class AboutPluginsUI extends JFrame {

        // Our components    
        JPanel jpnlUI;
        JButton jbtnOK;
        JTable table;
        PluginTableModel model;

        // Class Constructor            
        public AboutPluginsUI(EditPlugin plugins[]) {

            int length = plugins.length;
            
            // Start building the UI proper            
            setTitle("About Plugins");
            Font font = new Font("Helvetica", Font.BOLD, 12);
            getContentPane().setLayout(new BorderLayout());
            jbtnOK = new JButton("OK");
            getContentPane().add(jbtnOK, "South");
            
            model = new PluginTableModel(plugins);
            table = new JTable();
            table.setModel(model);
            table.createDefaultColumnsFromModel();
            table.setFont(font);
            
            getContentPane().add(JTable.createScrollPaneForTable(table), "Center");

            // Determine size and position of the GUI
            Dimension screen = getToolkit().getScreenSize();
            pack();
            setSize(getPreferredSize());
            setLocation((screen.width - getSize().width) / 2,
                (screen.height - getSize().height) / 2);
            show();
            setVisible(true);
            
            // Register listeners
            WindowCloser wCloser = new WindowCloser();
            this.addWindowListener(wCloser);
            ButListener butListener = new ButListener();
            jbtnOK.addActionListener(butListener);
        }
        
        // Close the UI when the OK button is hit
    	void jbtnOK_Action(ActionEvent event)	{

            this.setVisible(false);
            this.dispose();
    	}

        // Some utility classes for the UI
        class ButListener implements ActionListener {
            
            public void actionPerformed(ActionEvent event) {

                Object object = event.getSource();
    
    		    if (object == jbtnOK)	{
                    jbtnOK_Action(event);
    		    }
	    	}
    	} /* End of ButListener */
        
        class WindowCloser extends WindowAdapter {

	    	public void windowClosing(WindowEvent event) {

                Object object = event.getSource();
    
       			if (object == AboutPluginsUI.this) {
	                Window win = event.getWindow();
                    win.setVisible(false);
                    win.dispose();
                }
            }
    	} /* End of WindowCloser */

} /* End of Class */
