/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
/**
 * PluginTableModel - The View controller class for AboutPlugin 
 * 
 * @version     0.1.2    05/02/2000    First version
 *
 * @author      Todd Papaioannou
 * Copyright (C) 1999 Todd Papaioannou (toddp@acm.org)
 */

import java.io.*;
import java.util.*;
import javax.swing.*;
import javax.swing.table.*;
import javax.swing.event.*;
import org.gjt.sp.jedit.*;

public class PluginTableModel extends AbstractTableModel {
    
    protected Vector plugins;
    
    public PluginTableModel(EditPlugin plugs[]) {
        
        Plugin curPlugin;
        int i, j, max;
        
        plugins = new Vector();
        max = plugs.length;
        
        for(i = 0; i < max; i++) {
            
            // Let's determine what this PlugIn's name is
            String cname = plugs[i].getClass().getName();
            //System.out.println(cname + "\n");
            
            // Is this plugin even a plugin? And not a PlugPart?
            if (!cname.endsWith("Plugin")) continue;

            j = cname.lastIndexOf(".");
            
            // Let's handle some of Kevin Burton's dodgy naming ;)
            if (cname.startsWith("javainsight"))  
                cname = "JavaInsight";
            else if (j != -1) {
                
                cname = cname.substring(j+1, cname.length());
                
                if (cname.startsWith("Project"))  
                    cname = "ProjectViewer";
                    
                if (cname.endsWith("Plugin")) {
                    j = cname.lastIndexOf("Plugin");

                    if (j != -1)
                        cname = cname.substring(0, j);
                }
            }

            // Now let's try to get the Version
            String pname = jEdit.getProperty("plugin." + cname + ".name");
            String version = jEdit.getProperty("plugin." + cname + ".version");
            String author = jEdit.getProperty("plugin." + cname + ".author");

    System.out.println(pname + version + author);            
    
            if (pname != null && version != null && author != null) {
            
                curPlugin = new Plugin(pname, version, author);
                plugins.addElement(curPlugin);
            }    
        }
    }
        
    public int getRowCount() {
        return plugins.size();
    }
    
    public int getColumnCount() {
        return 3;
    }
    
    public String getColumnName(int columnIndex) {
        
        String retVal = "";
        
        switch(columnIndex) {
            
            case 0:
                retVal = "Plugin Name";
                break;
            case 1:
                retVal = "Version";
                break;
            case 2:
                retVal = "Author";
                break;
        }
        
        return retVal;
    }
    
    public Class getColumnClass(int columnIndex) {
        
        return String.class;
    }
    
    public boolean iscellEditable(int rowIndex, int columnIndex) {
        
        boolean retValue = false;
        return retValue;
    }
    
    public Object getValueAt(int rowIndex, int columnIndex) {
        
        Object retValue = null;
        Plugin plugin = null;
        
        if (rowIndex < plugins.size()) {
            plugin = (Plugin)plugins.elementAt(rowIndex);
        }
        
        if (plugin == null) 
            return "";
            
        if (columnIndex == 0) {
            return plugin.getName();
        }
        
        if (columnIndex == 1) {
            return plugin.getVersion();
        }
        
        if (columnIndex == 2) {
            return plugin.getAuthor();
        }
        
        return retValue;
    }
    
    public void setValueAt(Object aValue, int rowIndex, int columnIndex) { return; }

} /* End of Class */

/**
 * Plugin Data Structure 
 *
 */
class Plugin {
    
    // Our internal variables
    protected String name, version, author;
    
    public Plugin(String nm, String ver, String auth) {
        
        name = new String(nm);
        version = new String(ver);
        author = new String(auth);
    }    
            
    public String getName() {
        
        return name;
    }
    
    public String getVersion() {
        
        return version;
    }
    
    public String getAuthor() {
        
        return author;
    }
    
} /* End of Plugin */
